<head>
    <title>{% if page.title %}{{ page.title }} - {% endif %}{{ config.site_name }}</title>
    <meta charset="UTF-8"/>
    <meta name="description" content="{{ config['site_description'] }}"/>
    <meta name="keywords" content="mkdocs,documentation,curriculum-vitae"/>
    <link href="assets/mkdocs_curriculum_vitae.css" rel="stylesheet">
    {%- for path in config.extra_css %}
    <link href="{{ path | url }}" rel="stylesheet">
    {%- endfor %}
</head>
